Option Strict Off
Option Explicit On 
Public Class ClsVxmDriverVbNet2003
    '*** Use loadlibrary and getprocaddress to see if the driver functions exist
    Private Declare Function LoadLibrary Lib "kernel32" Alias "LoadLibraryA" (ByVal lpLibFileName As String) As Integer
    Private Declare Function GetProcAddress Lib "kernel32" (ByVal hModule As Integer, ByVal lpProcName As String) As Integer
    Private Declare Function CallWindowProc Lib "user32" Alias "CallWindowProcA" (ByVal lpPrevWndFunc As Integer, ByVal hwnd As Integer, ByVal Msg As Integer, ByVal wParam As Integer, ByVal lParam As Integer) As Integer
    Private Declare Function FreeLibrary Lib "kernel32" (ByVal hLibModule As Integer) As Integer
    Private Declare Sub CopyMemory Lib "kernel32" Alias "RtlMoveMemory" (ByRef lpDest As Long, ByRef lpSource As Long, ByVal cBytes As Integer)

    '*** VXM Driver Functions (use ONLY in VB6)
    Private Declare Function ShowTerminal Lib "VxmDriver.dll" Alias "ShowTerminalSimple" (ByVal ParentHwnd As Integer) As Integer
    Private Declare Function HideTerminal Lib "VxmDriver.dll" Alias "HideTerminalSimple" () As Integer
    Private Declare Function OpenPort Lib "VxmDriver.dll" (ByVal ComPortNumber As Integer, ByVal ComPortBaudRate As Integer) As Integer
    Private Declare Function IsPortOpen Lib "VxmDriver.dll" () As Integer
    Private Declare Function ClosePort Lib "VxmDriver.dll" () As Integer 'Close serial port
    Private Declare Function DriverSendToPort Lib "VxmDriver.dll" (ByVal CommandOut As String) As Integer 'Send Command
    Private Declare Function ReadFromPort Lib "VxmDriver.dll" () As String 'Get reply from device
    Private Declare Function CountCharsAtPort Lib "VxmDriver.dll" () As Integer 'Count Number of Chars at port
    Private Declare Function SearchForChars Lib "VxmDriver.dll" (ByVal CharsToFind As String) As Integer
    Private Declare Function ClearPort Lib "VxmDriver.dll" () As Integer 'Clear buffer
    Private Declare Function RemoveFromPort Lib "VxmDriver.dll" (ByVal StringToRemove As String) As Integer 'Clear buffer chars
    Private Declare Function GetMotorPosition Lib "VxmDriver.dll" (ByVal MotorNumber As Integer) As String
    Private Declare Function WaitForChar Lib "VxmDriver.dll" (ByVal CharToWaitFor As String, Optional ByVal TimeOutTime As Integer = 0) As Integer
    Private Declare Function WaitForCharWithMotorPosition Lib "VxmDriver.dll" (ByVal CharToWaitFor As String, ByVal MotorNumber As Integer, Optional ByVal ReportToWindowHwnd As Integer = 0, Optional ByVal TimeOutTime As Integer = 0) As Integer
    Private Declare Sub ResetDriverFunctions Lib "VxmDriver.dll" ()

    '*** Handle for Driver Functions
    Private hLib As Integer 'Driver
    Private hShowTerminal As Integer 'ShowTerminal
    Private hHideTerminal As Integer 'HideTerminal
    Private hPortOpen As Integer 'Port Open
    Private hPortClose As Integer 'Port Close
    Private hIsPortOpen As Integer 'Is Port Open
    Private hSendToPort As Integer 'Send to Port
    Private hReadFromPort As Integer 'Read from Port
    Private hCountChars As Integer 'Count Chars at Port
    Private hSearchForChars As Integer 'Search for Chars
    Private hClearPort As Integer 'Clear Port
    Private hRemoveFromPort As Integer 'Remove Chars from Port
    Private hGetMotorPosition As Integer 'Get Motor Position
    Private hWaitForChar As Integer 'Wait for Char
    Private hWaitForCharMotorPosition As Integer 'Wait for Char and Get Motor Position while waiting
    Private hResetDriverFunctions As Integer 'Reset Driver Functions for recovery	

    Public Sub New()
        MyBase.New()
    End Sub

    '*** Subroutine to clean up parameters after done with driver
    Protected Overrides Sub Finalize()
        releasedriver()
        MyBase.Finalize()
    End Sub



    '*** Subroutine to initialize parameters before running driver

    Public Function LoadDriver(ByVal PathToDll As String) As Integer
        hLib = LoadLibrary(PathToDll) 'Driver
        Select Case hLib
            Case 0
            Case Else
                hShowTerminal = GetProcAddress(hLib, "ShowTerminalSimple") 'ShowTerminal
                hHideTerminal = GetProcAddress(hLib, "HideTerminalSimple") 'HideTerminal
                hPortOpen = GetProcAddress(hLib, "OpenPort") 'Port Open
                hPortClose = GetProcAddress(hLib, "ClosePort") 'Port Close
                hIsPortOpen = GetProcAddress(hLib, "IsPortOpen") 'Is Port Open
                hSendToPort = GetProcAddress(hLib, "DriverSendToPort") 'Send to Port
                hReadFromPort = GetProcAddress(hLib, "ReadFromPort") 'Read from Port
                hCountChars = GetProcAddress(hLib, "CountCharsAtPort") 'Count Chars at Port
                hSearchForChars = GetProcAddress(hLib, "SearchForChars") 'Search for Chars
                hClearPort = GetProcAddress(hLib, "ClearPort") 'Clear Port
                hRemoveFromPort = GetProcAddress(hLib, "RemoveFromPort") 'Remove Chars from Port
                hGetMotorPosition = GetProcAddress(hLib, "GetMotorPosition") 'Get Motor Position
                hWaitForChar = GetProcAddress(hLib, "WaitForChar") 'Wait for Char
                hWaitForCharMotorPosition = GetProcAddress(hLib, "WaitForCharWithMotorPosition") 'Wait for Char and Get Motor Position while waiting
                hResetDriverFunctions = GetProcAddress(hLib, "ResetDriverFunctions") 'Reset Driver Functions for recovery
        End Select
        LoadDriver = hLib
    End Function

    Public Function ReleaseDriver()
        Select Case hPortClose
            Case 0
            Case Else
                ClosePort()
        End Select
        Select Case hHideTerminal
            Case 0
            Case Else
                HideTerminal()
        End Select
        Select Case hLib
            Case 0
            Case Else
                FreeLibrary(hLib)
        End Select
    End Function

    Public Function DriverTerminalShowState(ByVal StateToShow As Integer, Optional ByVal ParentHwnd As Integer = 0) As Integer
        Select Case StateToShow
            Case 0
                Select Case hHideTerminal 'Check if function exists
                    Case 0
                    Case Else
                        DriverTerminalShowState = HideTerminal 'Call function
                End Select
            Case 1
                Select Case hShowTerminal 'Check if function exists
                    Case 0
                    Case Else
                        Select Case ParentHwnd
                            Case 0
                                DriverTerminalShowState = ShowTerminal(0) 'Call function
                            Case Else
                                DriverTerminalShowState = ShowTerminal(ParentHwnd) 'Call function
                        End Select
                End Select
        End Select
    End Function

    Public Function PortOpen(ByVal PortNumber As Integer, ByVal BaudRate As Integer) As Integer
        Select Case hPortOpen 'Check if function exists
            Case 0
            Case Else
                Select Case PortNumber 'See if port is valid
                    Case Is < 1, Is > 255
                        PortOpen = 0
                    Case Else
                        Select Case BaudRate 'See if baudrate is valid
                            Case 9600, 19200, 38400
                                PortOpen = OpenPort(PortNumber, BaudRate) 'Call function
                            Case Else
                                PortOpen = 0
                        End Select
                End Select
        End Select
    End Function

    Public Function PortClose() As Integer
        Select Case hPortClose
            Case 0 'See if function exists
            Case Else
                PortClose = ClosePort 'Call function
        End Select
    End Function

    Public Function PortIsOpen() As Integer
        Select Case hIsPortOpen 'See if function exists
            Case 0
            Case Else
                PortIsOpen = IsPortOpen 'Call function
        End Select
    End Function

    Public Function PortSendCommands(ByVal CommandToSend As String) As Integer
        Select Case hSendToPort 'See if function exists
            Case 0
            Case Else
                PortSendCommands = DriverSendToPort(CommandToSend) 'Call function
        End Select
    End Function

    Public Function PortReadReply() As String
        Select Case hReadFromPort 'See if function exists
            Case 0
            Case Else
                PortReadReply = ReadFromPort 'Call function
        End Select
    End Function

    Public Function PortCountChars() As Integer
        Select Case hCountChars 'See if function exists
            Case 0
            Case Else
                PortCountChars = CountCharsAtPort 'Call function
        End Select
    End Function

    Public Function PortSearchForChars(ByVal CharsToFind As String) As Integer
        Select Case hSearchForChars 'See if function exists
            Case 0
            Case Else
                PortSearchForChars = SearchForChars(CharsToFind) 'Call function
        End Select
    End Function

    Public Function PortClear() As Integer
        Select Case hClearPort 'See if function exists
            Case 0
            Case Else
                PortClear = ClearPort 'Call function
        End Select
    End Function

    Public Function PortRemoveChars(ByVal StringToRemove As String) As Integer
        Select Case hRemoveFromPort 'See if function exists
            Case 0
            Case Else
                PortRemoveChars = RemoveFromPort(StringToRemove) 'Call function
        End Select
    End Function

    Public Function MotorPosition(ByVal MotorNumber As Integer) As String
        Select Case hGetMotorPosition 'See if function exists
            Case 0
            Case Else
                MotorPosition = GetMotorPosition(MotorNumber) 'Call function
        End Select
    End Function

    Public Function PortWaitForChar(ByVal CharToWaitFor As String, Optional ByVal TimeOutTime As Integer = 0) As Integer
        Select Case hWaitForChar 'See if function exists
            Case 0
            Case Else
                Select Case TimeOutTime
                    Case 0
                        PortWaitForChar = WaitForChar(CharToWaitFor) 'Call function
                    Case Else
                        PortWaitForChar = WaitForChar(CharToWaitFor, TimeOutTime) 'Call function
                End Select
        End Select
    End Function

    Public Function PortWaitForCharWithMotorPosition(ByVal CharToWaitFor As String, Optional ByVal TimeOutTime As Integer = 0) As Integer
        Select Case hWaitForCharMotorPosition 'See if function exists
            Case 0
            Case Else
                Select Case TimeOutTime
                    Case 0
                        PortWaitForCharWithMotorPosition = WaitForCharWithMotorPosition(CharToWaitFor, TimeOutTime) 'Call function
                    Case Else
                        PortWaitForCharWithMotorPosition = WaitForCharWithMotorPosition(CharToWaitFor, TimeOutTime) 'Call function
                End Select
        End Select
    End Function

    Public Sub DriverResetFunctions()
        Select Case hResetDriverFunctions 'See if sub exists
            Case 0
            Case Else
                ResetDriverFunctions() 'Call sub
        End Select
    End Sub
End Class
